<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>EventDialog</name>
    <message>
      <source>Event Editor</source>
      <translation>Редактор cобытий</translation>
    </message>
    <message>
      <source>Label:</source>
      <translation>Метка:</translation>
    </message>
    <message>
      <source>Name:</source>
      <translation>Название:</translation>
    </message>
    <message>
      <source>Type:</source>
      <translation>Тип:</translation>
    </message>
    <message>
      <source>House event</source>
      <extracomment>Constant event w/ Boolean state value</extracomment>
      <translation>Постоянное событие</translation>
    </message>
    <message>
      <source>Basic event</source>
      <extracomment>The main analysis event (e.g., component failure)</extracomment>
      <translation>Основное событие</translation>
    </message>
    <message>
      <source>Undeveloped</source>
      <extracomment>The basic event flavor that indicates the further developement into a gate is possible.</extracomment>
      <translation>Неразвивающееся</translation>
    </message>
    <message>
      <source>Conditional</source>
      <extracomment>Conditioning flavor for a basic event (used as a conditioning variable for conditional probabilities)</extracomment>
      <translation>Событие условие</translation>
    </message>
    <message>
      <source>Gate</source>
      <extracomment>The intermediary w/ a Boolean formula as a definition. Defines the logic and interdependencies of the fault tree.</extracomment>
      <translation>Вентиль</translation>
    </message>
    <message>
      <source>State:</source>
      <translation>Состояние:</translation>
    </message>
    <message>
      <source>False</source>
      <translation>Нет</translation>
    </message>
    <message>
      <source>True</source>
      <translation>Да</translation>
    </message>
    <message>
      <source>Expression</source>
      <translation>Выражение</translation>
    </message>
    <message>
      <source>Value:</source>
      <translation>Значение:</translation>
    </message>
    <message>
      <source>Rate:</source>
      <translation>Интенсивность:</translation>
    </message>
    <message>
      <source>Connective:</source>
      <translation>Операция:</translation>
    </message>
    <message>
      <source>AND</source>
      <translation>И</translation>
    </message>
    <message>
      <source>OR</source>
      <translation>ИЛИ</translation>
    </message>
    <message>
      <source>ATLEAST</source>
      <extracomment>VOTE, Voting OR, Combo, Combination, K/N gate</extracomment>
      <translation>Выборка</translation>
    </message>
    <message>
      <source>XOR</source>
      <extracomment>Exclusive OR</extracomment>
      <translation>ИЛИ-ИСКЛ</translation>
    </message>
    <message>
      <source>NOT</source>
      <translation>НЕ</translation>
    </message>
    <message>
      <source>NAND</source>
      <extracomment>NOT AND</extracomment>
      <translation>И-НЕ</translation>
    </message>
    <message>
      <source>NOR</source>
      <extracomment>NOT OR</extracomment>
      <translation>ИЛИ-НЕ</translation>
    </message>
    <message>
      <source>Min:</source>
      <translation>Минимум:</translation>
    </message>
    <message>
      <source>Add argument with its ID</source>
      <translation>Добавьте аргумент с ID</translation>
    </message>
    <message>
      <source>Add Argument</source>
      <translation>Добавить аргумент</translation>
    </message>
    <message>
      <source>Remove Argument</source>
      <translation>Удалить аргумент</translation>
    </message>
    <message>
      <source>Container</source>
      <translation>Контейнер</translation>
    </message>
    <message>
      <source>Fault tree:</source>
      <translation>Дерево отказов:</translation>
    </message>
    <message>
      <source>Model</source>
      <translation>Модель</translation>
    </message>
    <message>
      <source>Constant</source>
      <comment>constant probability value</comment>
      <translation>Константа</translation>
    </message>
    <message>
      <source>Exponential</source>
      <comment>probability type defined w/ negative exponential formula</comment>
      <translation>Экспоненциал</translation>
    </message>
    <message>
      <source>NULL</source>
      <comment>Not a null value.</comment>
      <extracomment>Pass-through, NO-OP type</extracomment>
      <translation>Пропуск</translation>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <source>&amp;Help</source>
      <translation>&amp;Справка</translation>
    </message>
    <message>
      <source>&amp;File</source>
      <translation>&amp;Файл</translation>
    </message>
    <message>
      <source>&amp;View</source>
      <translation>&amp;Вид</translation>
    </message>
    <message>
      <source>&amp;Zoom</source>
      <translation>&amp;Масштаб</translation>
    </message>
    <message>
      <source>&amp;Toolbars</source>
      <translation>&amp;Панели инструментов</translation>
    </message>
    <message>
      <source>&amp;Analysis</source>
      <translation>&amp;Анализ</translation>
    </message>
    <message>
      <source>&amp;Edit</source>
      <translation>&amp;Правка</translation>
    </message>
    <message>
      <source>Model Tool Bar</source>
      <translation>Панель модели</translation>
    </message>
    <message>
      <source>Edit Tool Bar</source>
      <translation>Панель редактирования</translation>
    </message>
    <message>
      <source>Zoom Tool Bar</source>
      <translation>Панель масштаб</translation>
    </message>
    <message>
      <source>Analysis Tool Bar</source>
      <translation>Панель анализа</translation>
    </message>
    <message>
      <source>Data</source>
      <translation>Данные</translation>
    </message>
    <message>
      <source>Reports</source>
      <translation>Отчеты</translation>
    </message>
    <message>
      <source>About &amp;Qt</source>
      <translation>О &amp;Qt</translation>
    </message>
    <message>
      <source>About the Qt toolkit</source>
      <translation>О Qt</translation>
    </message>
    <message>
      <source>About &amp;SCRAM</source>
      <translation>О &amp;SCRAM</translation>
    </message>
    <message>
      <source>E&amp;xit</source>
      <translation>В&amp;ыход</translation>
    </message>
    <message>
      <source>Exit the Application</source>
      <translation>Выход из приложения</translation>
    </message>
    <message>
      <source>&amp;New Model</source>
      <translation>&amp;Новая модель</translation>
    </message>
    <message>
      <source>Create a New Model</source>
      <translation>Создать новую модель</translation>
    </message>
    <message>
      <source>&amp;Open Model Files...</source>
      <translation>&amp;Открыть файлы модели...</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Открыть файлы модели</translation>
    </message>
    <message>
      <source>&amp;Save Model</source>
      <translation>&amp;Сохранить модель</translation>
    </message>
    <message>
      <source>Save Model &amp;As...</source>
      <translation>Сохранить модель &amp;как...</translation>
    </message>
    <message>
      <source>&amp;Print...</source>
      <translation>&amp;Печать...</translation>
    </message>
    <message>
      <source>Print</source>
      <translation>Печать</translation>
    </message>
    <message>
      <source>&amp;Export As...</source>
      <translation>&amp;Экспортировать как...</translation>
    </message>
    <message>
      <source>Zoom &amp;In</source>
      <translation>&amp;Увеличить</translation>
    </message>
    <message>
      <source>Zoom &amp;Out</source>
      <translation>У&amp;меньшить</translation>
    </message>
    <message>
      <source>Best &amp;Fit</source>
      <translation>Подог&amp;нать</translation>
    </message>
    <message>
      <source>Run Analysis</source>
      <translation>Запуск анализа</translation>
    </message>
    <message>
      <source>Analysis Settings</source>
      <translation>Параметры анализа</translation>
    </message>
    <message>
      <source>&amp;Model</source>
      <translation>&amp;Модель</translation>
    </message>
    <message>
      <source>&amp;Data</source>
      <translation>&amp;Данные</translation>
    </message>
    <message>
      <source>&amp;Reports</source>
      <translation>&amp;Отчеты</translation>
    </message>
    <message>
      <source>Print Previe&amp;w...</source>
      <translation>Просмотр печат&amp;и...</translation>
    </message>
    <message>
      <source>&amp;Add Element</source>
      <translation>&amp;Добавить элемент</translation>
    </message>
    <message>
      <source>Re&amp;move Element</source>
      <translation>&amp;Удалить элемент</translation>
    </message>
    <message>
      <source>Export &amp;Report As...</source>
      <translation>Экспортировать &amp;отчет...</translation>
    </message>
    <message>
      <source>Re&amp;name Model</source>
      <translation>&amp;Переименовать модель</translation>
    </message>
    <message>
      <source>&amp;Run</source>
      <comment>execute analysis</comment>
      <translation>&amp;Запустить</translation>
    </message>
    <message>
      <source>&amp;Settings...</source>
      <comment>analysis configuration</comment>
      <translation>&amp;Настройки...</translation>
    </message>
    <message>
      <source>Recent &amp;Files</source>
      <translation>Последние &amp;файлы</translation>
    </message>
    <message>
      <source>&amp;Preferences...</source>
      <translation>&amp; Предпочтения...</translation>
    </message>
    <message>
      <source>&amp;Clear List</source>
      <translation>&amp;Очистить список</translation>
    </message>
  </context>
  <context>
    <name>NameDialog</name>
    <message>
      <source>Name Edit</source>
      <translation>Изменить название</translation>
    </message>
    <message>
      <source>Name:</source>
      <translation>Название:</translation>
    </message>
  </context>
  <context>
    <name>PreferencesDialog</name>
    <message>
      <source>Preferences</source>
      <translation>Предпочтения</translation>
    </message>
    <message>
      <source>Language:</source>
      <translation>Язык:</translation>
    </message>
    <message>
      <source>Undo limit:</source>
      <translation>Лимит отмен:</translation>
    </message>
    <message>
      <source>Auto-save:</source>
      <translation>Автосохранение:</translation>
    </message>
    <message>
      <source>min</source>
      <extracomment>Shortened time unit for &apos;minutes&apos;</extracomment>
      <translation>мин</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Set element &apos;%1&apos; label to &apos;%2&apos;</source>
      <translation>Установить метку элемента «%1» на «%2»</translation>
    </message>
    <message>
      <source>Modify basic event &apos;%1&apos; expression</source>
      <translation>Изменить выражение основного события «%1»</translation>
    </message>
    <message>
      <source>Set house event &apos;%1&apos; state to &apos;%2&apos;</source>
      <translation>Установить состояние постоянного события «%1» на «%2»</translation>
    </message>
    <message>
      <source>Update gate &apos;%1&apos; formula</source>
      <translation>Изменить формулу вентиля «%1»</translation>
    </message>
    <message>
      <source>Rename model to &apos;%1&apos;</source>
      <translation>Переименовать модель на «%1»</translation>
    </message>
    <message>
      <source>Add fault tree &apos;%1&apos;</source>
      <translation>Добавить дерево отказов «%1»</translation>
    </message>
    <message>
      <source>Remove fault tree &apos;%1&apos;</source>
      <translation>Удалить дерево отказов «%1»</translation>
    </message>
    <message>
      <source>Rename event &apos;%1&apos; to &apos;%2&apos;</source>
      <translation>Переименовать событие «%1» в «%2»</translation>
    </message>
    <message>
      <source>True</source>
      <translation>Да</translation>
    </message>
    <message>
      <source>False</source>
      <translation>Нет</translation>
    </message>
    <message>
      <source>Add event &apos;%1&apos;</source>
      <translation>Добавить событие «%1»</translation>
    </message>
    <message>
      <source>Remove event &apos;%1&apos;</source>
      <translation>Удалить событие «%1»</translation>
    </message>
    <message>
      <source>Change the type of event &apos;%1&apos;</source>
      <translation>Изменить тип события «%1»</translation>
    </message>
    <message>
      <source>IO Error</source>
      <translation>Ошибка ввода-вывода</translation>
    </message>
    <message>
      <source>File: %1</source>
      <translation>Файл: %1</translation>
    </message>
    <message>
      <source>Line: %1</source>
      <translation>Строка: %1</translation>
    </message>
    <message>
      <source>MEF Container: %1</source>
      <translation>ФОМ контейнер: %1</translation>
    </message>
    <message>
      <source>XML element: %1</source>
      <translation>XML-элемент: %1</translation>
    </message>
    <message>
      <source>XML attribute: %1</source>
      <translation>Атрибут XML: %1</translation>
    </message>
  </context>
  <context>
    <name>SettingsDialog</name>
    <message>
      <source>Analysis Settings</source>
      <translation>Настройки анализа</translation>
    </message>
    <message>
      <source>Approximations</source>
      <translation>Приближения</translation>
    </message>
    <message>
      <source>Rare-event</source>
      <translation>Редкое событие</translation>
    </message>
    <message>
      <source>Analyses</source>
      <translation>Анализы</translation>
    </message>
    <message>
      <source>Prime implicants</source>
      <translation>Простая импликанта</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Вероятность</translation>
    </message>
    <message>
      <source>Importance</source>
      <translation>Важность</translation>
    </message>
    <message>
      <source>Algorithms</source>
      <translation>Алгоритмы</translation>
    </message>
    <message>
      <source>Limits</source>
      <translation>Ограничения</translation>
    </message>
    <message>
      <source>Mission time:</source>
      <translation>Продолжительность миссии:</translation>
    </message>
    <message>
      <source>Product order:</source>
      <translation>Мощность произведения:</translation>
    </message>
  </context>
  <context>
    <name>StartPage</name>
    <message>
      <source>Start Here</source>
      <translation>Начало работы</translation>
    </message>
    <message>
      <source>Start a New Model</source>
      <translation>Создать новую модель</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Открыть файлы модели</translation>
    </message>
    <message>
      <source>Example Models</source>
      <translation>Примеры</translation>
    </message>
    <message>
      <source>Recent Files</source>
      <translation>Последние файлы</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::DiagramView</name>
    <message>
      <source>Export As</source>
      <translation>Экспортировать как</translation>
    </message>
    <message>
      <source>SVG files (*.svg);;All files (*.*)</source>
      <translation>SVG файлы (*.svg); Все файлы (*. *)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::EventDialog</name>
    <message>
      <source>House event</source>
      <translation>Постоянное событие</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; is already in formula.</source>
      <extracomment>Duplicate arguments are not allowed in a formula.</extracomment>
      <translation>Аргумент «%1» уже в формуле.</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; would introduce a self-cycle.</source>
      <extracomment>Self-cycle is also called a loop in a graph.</extracomment>
      <translation>Аргумент «%1» ввел бы петлю.</translation>
    </message>
    <message>
      <source>The argument &apos;%1&apos; would introduce a cycle.</source>
      <extracomment>Fault trees are acyclic graphs.</extracomment>
      <translation>Аргумент «%1» ввел бы цикл.</translation>
    </message>
    <message>
      <source>The event with name &apos;%1&apos; already exists.</source>
      <extracomment>Duplicate event definition in the model.</extracomment>
      <translation>Событие с названием «%1» уже существует.</translation>
    </message>
    <message>
      <source>Name &apos;%1&apos; would introduce a self-cycle.</source>
      <translation>Название «%1» ввел бы петлю.</translation>
    </message>
    <message>
      <source>%1 connective requires a single argument.</source>
      <translation>%1 операция требует один обязательный аргумент.</translation>
    </message>
    <message>
      <source>%1 connective requires 2 or more arguments.</source>
      <translation>%1 операция требует 2 или более аргументы.</translation>
    </message>
    <message>
      <source>%1 connective requires exactly 2 arguments.</source>
      <translation>%1 операция требует 2 обязательных аргументы.</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; is already defined with a top gate.</source>
      <extracomment>Fault tree redefinition.</extracomment>
      <translation>Дерево отказов «%1» уже определен с главным событием.</translation>
    </message>
    <message numerus="yes">
      <source>%1 connective requires at-least %n arguments.</source>
      <extracomment>The number of required arguments is always more than 2.</extracomment>
      <translation>
        <numerusform>%1 операция требует по крайней мере %n аргумент.</numerusform>
        <numerusform>%1 операция требует по крайней мере %n аргументы.</numerusform>
        <numerusform>%1 операция требует по крайней мере %n аргументы.</numerusform>
      </translation>
    </message>
  </context>
  <context>
    <name>scram::gui::MainWindow</name>
    <message>
      <source>Validation Error</source>
      <translation>Ошибка при валидации</translation>
    </message>
    <message>
      <source>Not all basic events have expressions for probability analysis.</source>
      <translation>Не все основные события имеют выражения для анализа вероятности.</translation>
    </message>
    <message>
      <source>Running analysis...</source>
      <extracomment>This is a message shown during the analysis run.</extracomment>
      <translation>Выполнение анализа...</translation>
    </message>
    <message>
      <source>Configuration Error</source>
      <translation>Ошибка конфигурации</translation>
    </message>
    <message>
      <source>Initialization Error</source>
      <extracomment>The error upon initialization from a file.</extracomment>
      <translation>Ошибка инициализации</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; must have a single top-gate.</source>
      <extracomment>Single top/root event fault tree are expected by GUI.</extracomment>
      <translation>Дерево отказов «%1» должно иметь единственное главное событие.</translation>
    </message>
    <message>
      <source>Find/Filter (Perl Regex)</source>
      <extracomment>The search bar.</extracomment>
      <translation>Поиск/фильтр (Perl регулярное выражение)</translation>
    </message>
    <message>
      <source>About SCRAM</source>
      <translation>О SCRAM</translation>
    </message>
    <message>
      <source>Undo:</source>
      <translation>Отменить:</translation>
    </message>
    <message>
      <source>Redo:</source>
      <translation>Повторить:</translation>
    </message>
    <message>
      <source>Save Model?</source>
      <translation>Сохранить модель?</translation>
    </message>
    <message>
      <source>Save changes to model &apos;%1&apos; before closing?</source>
      <translation>Сохранить изменения в модель «%1» перед закрытием?</translation>
    </message>
    <message>
      <source>Open Model Files</source>
      <translation>Открыть файлы модели</translation>
    </message>
    <message>
      <source>Model Exchange Format</source>
      <translation>Формат обмена моделей</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Все файлы</translation>
    </message>
    <message>
      <source>Save Model As</source>
      <translation>Сохранить модель как</translation>
    </message>
    <message>
      <source>Export Report As</source>
      <translation>Экспортировать отчеты</translation>
    </message>
    <message>
      <source>Dependency Container Removal</source>
      <extracomment>The container w/ dependents still in the model.</extracomment>
      <translation>Удаление контейнера c иждивенцами</translation>
    </message>
    <message>
      <source>Fault tree &apos;%1&apos; with root &apos;%2&apos; is not removable because it has dependent non-root gates. Remove the gates from the fault tree before this operation.</source>
      <translation>Дерево отказов «%1» с главным событием «%2» не является удаляемым, потому что оно имеет вентиля иждевенцы. Удалите вентиля из дерева отказов до этой операции.</translation>
    </message>
    <message>
      <source>Remove fault tree &apos;%1&apos; with root &apos;%2&apos;</source>
      <translation>Удалить дерево отказов «%1» с главным событием «%2»</translation>
    </message>
    <message>
      <source>Dependency Event Removal</source>
      <extracomment>The event w/ dependents in the model.</extracomment>
      <translation>Удаление события c иждивенцами</translation>
    </message>
    <message>
      <source>Event &apos;%1&apos; is not removable because it has dependents. Remove the event from the dependents before this operation.</source>
      <translation>Событие «%1» не является удаляемым, потому что оно имеет иждивенцев. Удалите событие из иждивенцев до этой операции.</translation>
    </message>
    <message>
      <source>Add fault tree &apos;%1&apos; with gate &apos;%2&apos;</source>
      <extracomment>Addition of a fault by defining its root event first.</extracomment>
      <translation>Добавить дерево отказов «%1» с главным событием «%2»</translation>
    </message>
    <message>
      <source>Gates</source>
      <extracomment>The tab for the table of gates.</extracomment>
      <translation>Вентили</translation>
    </message>
    <message>
      <source>Basic Events</source>
      <extracomment>The tab for the table of basic events.</extracomment>
      <translation>Основные события</translation>
    </message>
    <message>
      <source>House Events</source>
      <extracomment>The tab for the table of house events.</extracomment>
      <translation>Постоянные события</translation>
    </message>
    <message>
      <source>Fault Tree: %1</source>
      <extracomment>The tab for a fault tree diagram.</extracomment>
      <translation>Дерево отказов: %1</translation>
    </message>
    <message>
      <source>Products: %1</source>
      <translation>Произведения: %1</translation>
    </message>
    <message>
      <source>Importance: %1</source>
      <translation>Важность: %1</translation>
    </message>
    <message>
      <source>&lt;h1&gt;SCRAM %1&lt;/h1&gt;The GUI front-end for SCRAM,&lt;br/&gt;a command-line risk analysis multi-tool.&lt;br/&gt;&lt;br/&gt;License: GPLv3+&lt;br/&gt;Homepage: &lt;a href=&quot;%2&quot;&gt;%2&lt;/a&gt;&lt;br/&gt;Technical Support: &lt;a href=&quot;%3&quot;&gt;%3&lt;/a&gt;&lt;br/&gt;Bug Tracker: &lt;a href=&quot;%4&quot;&gt;%4&lt;/a&gt;&lt;br/&gt;&lt;br/&gt;%5</source>
      <translation>&lt;h1&gt;SCRAM %1&lt;/h1&gt;Графический интерфейс для SCRAM,&lt;br/&gt; мулти инструмент командной строки для анализа рисков.&lt;br/&gt;&lt;br/&gt;Лицензия: GPLv3+&lt;br/&gt;Домашняя страница: &lt;a href=&quot;%2&quot;&gt;%2&lt;/a&gt;&lt;br/&gt;Техподдержка: &lt;a href=&quot;%3&quot;&gt;%3&lt;/a&gt;&lt;br/&gt;Баг-трекер: &lt;a href=&quot;%4&quot;&gt;%4&lt;/a&gt;&lt;br/&gt;&lt;br/&gt;%5</translation>
    </message>
    <message>
      <source>Configuration file error</source>
      <translation>Ошибка файла конфигурации</translation>
    </message>
    <message>
      <source>XML Validity Error</source>
      <translation>Ошибка XML</translation>
    </message>
    <message>
      <source>Invalid configuration file</source>
      <translation>Недопустимая конфигурация</translation>
    </message>
    <message>
      <source>Invalid configurations</source>
      <translation>Недопустимая конфигурация</translation>
    </message>
    <message>
      <source>Input file error</source>
      <translation>Ошибка входного файла</translation>
    </message>
    <message>
      <source>Invalid input file</source>
      <translation>Недопустимый входной файл</translation>
    </message>
    <message>
      <source>Invalid input model</source>
      <translation>Недопустимая модель</translation>
    </message>
    <message>
      <source>Unnamed Model</source>
      <translation>Безымянная модель</translation>
    </message>
    <message>
      <source>Save error</source>
      <comment>error on saving to file</comment>
      <translation>Ошибка сохранения</translation>
    </message>
    <message>
      <source>Reporting error</source>
      <translation>Ошибка при отчете</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::ModelTree</name>
    <message>
      <source>Fault Trees (%L1)</source>
      <extracomment>The parent item for collections of fault trees in the model.</extracomment>
      <translation>Деревья отказов (%L1)</translation>
    </message>
    <message>
      <source>Gates (%L1)</source>
      <extracomment>The table of gates.</extracomment>
      <translation>Вентили (%L1)</translation>
    </message>
    <message>
      <source>Basic Events (%L1)</source>
      <extracomment>The table of basic events.</extracomment>
      <translation>Основные события (%L1)</translation>
    </message>
    <message>
      <source>House Events (%L1)</source>
      <extracomment>The table of house events.</extracomment>
      <translation>Постоянные события (%L1)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::PreferencesDialog</name>
    <message>
      <source>Restart Required</source>
      <translation>Требуется перезапуск</translation>
    </message>
    <message>
      <source>The language change will take effect after an application restart.</source>
      <translation>Языковые изменения вступят в силу после перезапуска приложения.</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::ReportTree</name>
    <message>
      <source>Products (%L1)</source>
      <translation>Произведения (%L1)</translation>
    </message>
    <message>
      <source>Probability (%1)</source>
      <translation>Вероятность (%1)</translation>
    </message>
    <message>
      <source>Importance Factors (%L1)</source>
      <translation>Факторы важности (%L1)</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::BasicEvent</name>
    <message>
      <source>Set basic event &apos;%1&apos; flavor to &apos;%2&apos;</source>
      <translation>Установить вид основного события «%1» на «%2»</translation>
    </message>
    <message>
      <source>Basic</source>
      <translation>Основное</translation>
    </message>
    <message>
      <source>Undeveloped</source>
      <translation>Неразвивающееся</translation>
    </message>
    <message>
      <source>Conditional</source>
      <extracomment>Actually, this is &apos;conditioning&apos; since the event is the condition for some sub-tree.</extracomment>
      <translation>Условие</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::BasicEventContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Flavor</source>
      <extracomment>The flavor type of a basic event.</extracomment>
      <translation>Вид</translation>
    </message>
    <message>
      <source>Probability</source>
      <extracomment>In PRA context, probability may be unavailability or unreliability.</extracomment>
      <translation>Вероятность</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Метка</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::Gate</name>
    <message>
      <source>and</source>
      <translation>и</translation>
    </message>
    <message>
      <source>or</source>
      <translation>или</translation>
    </message>
    <message>
      <source>at-least %1</source>
      <extracomment>Also named as &apos;vote&apos;, &apos;voting or&apos;, &apos;combination&apos;, &apos;combo&apos;.</extracomment>
      <translation>выборка %1</translation>
    </message>
    <message>
      <source>xor</source>
      <translation>или-искл</translation>
    </message>
    <message>
      <source>not</source>
      <translation>не</translation>
    </message>
    <message>
      <source>null</source>
      <extracomment>This is &apos;pass-through&apos; or &apos;no-action&apos; gate type.</extracomment>
      <translation>пропуск</translation>
    </message>
    <message>
      <source>nand</source>
      <extracomment>not and.</extracomment>
      <translation>и-не</translation>
    </message>
    <message>
      <source>nor</source>
      <extracomment>not or.</extracomment>
      <translation>или-не</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::GateContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Connective</source>
      <extracomment>Boolean operator of the Boolean formula.</extracomment>
      <translation>Операция</translation>
    </message>
    <message>
      <source>Args</source>
      <extracomment>The number of arguments in the Boolean formula.</extracomment>
      <translation>Аргументы</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Метка</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::HouseEventContainerModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>State</source>
      <extracomment>House event Boolean state.</extracomment>
      <translation>Состояние</translation>
    </message>
    <message>
      <source>Label</source>
      <translation>Метка</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::ImportanceTableModel</name>
    <message>
      <source>ID</source>
      <translation>ID</translation>
    </message>
    <message>
      <source>Occurrence</source>
      <translation>Возникновение</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Вероятность</translation>
    </message>
    <message>
      <source>MIF</source>
      <translation>МФВ</translation>
    </message>
    <message>
      <source>CIF</source>
      <translation>КФВ</translation>
    </message>
    <message>
      <source>DIF</source>
      <translation>ДФВ</translation>
    </message>
    <message>
      <source>RAW</source>
      <translation>ЦДР</translation>
    </message>
    <message>
      <source>RRW</source>
      <translation>ЦУР</translation>
    </message>
  </context>
  <context>
    <name>scram::gui::model::ProductTableModel</name>
    <message>
      <source>Product</source>
      <translation>Произведение</translation>
    </message>
    <message>
      <source>Order</source>
      <translation>Мощность</translation>
    </message>
    <message>
      <source>Probability</source>
      <translation>Вероятность</translation>
    </message>
    <message>
      <source>Contribution</source>
      <translation>Вклад</translation>
    </message>
  </context>
</TS>
